<cfcomponent hint="Blog monitor methods" displayname="Blog monitor" output="false">

	<cfscript>
		VARIABLES.dsn = APPLICATION.blog.getProperty('dsn');
		VARIABLES.username = APPLICATION.blog.getProperty('username');
		VARIABLES.password = APPLICATION.blog.getProperty('password');
	</cfscript>

	<cffunction name="getData" returntype="struct" description="Retrieves packet of data for Blog Monitor remote call" access="remote" output="false">
		<cfscript>
			var dataPacket = {};
			dataPacket['totalViews'] = ['Total Views', totalViews()];
			dataPacket['totalApprovedComments'] = ['Approved Comments', totalApprovedComments()];
			dataPacket['totalUnapprovedComments'] = ['Unapproved Comments', totalUnapprovedComments()];
			dataPacket['totalActivePosts'] = ['Active Posts', totalActivePosts()];
			dataPacket['totalInactivePosts'] = ['Draft Posts', totalInactivePosts()];
			dataPacket['totalSearches'] = ['Total Searches', totalSearches()];
			dataPacket['recentSearchTerms'] = ['Recent Search Terms',recentSearchTerms(3)];
			dataPacket['totalSubscribers'] = ['Total Subscribers',totalSubscribers(5)];
			dataPacket['avgCommentsPerPost'] = ['Avg Comments Per Post', Ceiling(dataPacket['totalApprovedComments'][2] / dataPacket['totalActivePosts'][2])];
		</cfscript>
		<cfreturn dataPacket>
	</cffunction>

	<cffunction name="totalViews" returntype="numeric" access="public" output="false">
		<cfset var qry = ''>
		<cfquery name="qry" datasource="#VARIABLES.dsn#" username="#VARIABLES.username#" password="#VARIABLES.password#">
			SELECT SUM(views) AS cnt
			FROM tblblogentries
			WHERE released = 1
		</cfquery>
		<cfreturn qry.cnt>
	</cffunction>

	<cffunction name="totalApprovedComments" returntype="numeric" access="public" output="false">
		<cfset var qry = ''>
		<cfquery name="qry" datasource="#VARIABLES.dsn#" username="#VARIABLES.username#" password="#VARIABLES.password#">
			SELECT COUNT(*) AS cnt
			FROM tblblogcomments
			WHERE moderated = 1
		</cfquery>
		<cfreturn qry.cnt>
	</cffunction>

	<cffunction name="totalUnapprovedComments" returntype="numeric" access="public" output="false">
		<cfset var qry = ''>
		<cfquery name="qry" datasource="#VARIABLES.dsn#" username="#VARIABLES.username#" password="#VARIABLES.password#">
			SELECT COUNT(*) AS cnt
			FROM tblblogcomments
			WHERE moderated = 0
		</cfquery>
		<cfreturn qry.cnt>
	</cffunction>

	<cffunction name="totalActivePosts" returntype="numeric" access="public" output="false">
		<cfset var qry = ''>
		<cfquery name="qry" datasource="#VARIABLES.dsn#" username="#VARIABLES.username#" password="#VARIABLES.password#">
			SELECT COUNT(*) AS cnt
			FROM tblblogentries
			WHERE released = 1
		</cfquery>
		<cfreturn qry.cnt>
	</cffunction>

	<cffunction name="totalInactivePosts" returntype="numeric" access="public" output="false">
		<cfset var qry = ''>
		<cfquery name="qry" datasource="#VARIABLES.dsn#" username="#VARIABLES.username#" password="#VARIABLES.password#">
			SELECT COUNT(*) AS cnt
			FROM tblblogentries
			WHERE released = 0
		</cfquery>
		<cfreturn qry.cnt>
	</cffunction>

	<cffunction name="totalSearches" returntype="numeric" access="public" output="false">
		<cfset var qry = ''>
		<cfquery name="qry" datasource="#VARIABLES.dsn#" username="#VARIABLES.username#" password="#VARIABLES.password#">
			SELECT COUNT(searchterm) as cnt
			FROM tblblogsearchstats
		</cfquery>
		<cfreturn qry.cnt>
	</cffunction>

	<cffunction name="recentSearchTerms" returntype="string" access="public" output="false">
		<cfargument name="cnt" required="true" type="numeric" default="3">
		<cfset var qry = ''>
		<cfquery name="qry" datasource="#VARIABLES.dsn#" username="#VARIABLES.username#" password="#VARIABLES.password#">
			SELECT DISTINCT searchterm
			FROM tblblogsearchstats
			ORDER BY searched DESC
			LIMIT 0,#ARGUMENTS.cnt#
		</cfquery>
		<cfreturn ReplaceNoCase(ValueList(qry.searchterm),',',', ','ALL')>
	</cffunction>

	<cffunction name="totalSubscribers" returntype="string" access="public" output="false">
		<cfset var qry = ''>
		<cfquery name="qry" datasource="#VARIABLES.dsn#" username="#VARIABLES.username#" password="#VARIABLES.password#">
			SELECT COUNT(email) AS cnt
			FROM tblblogsubscribers
			GROUP BY email
		</cfquery>
		<cfreturn Iif(qry.cnt EQ '',0,qry.cnt)>
	</cffunction>

</cfcomponent>